==> huaweicloudsdkeg-3.1.135-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/invocation_http_parameters.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InvocationHttpParameters:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'header_parameters': 'list[HeaderParameter]'
    }

    attribute_map = {
        'header_parameters': 'header_parameters'
    }

    def __init__(self, header_parameters=None):
        """InvocationHttpParameters

        The model defined in huaweicloud sdk

        :param header_parameters: 对象列表
        :type header_parameters: list[:class:`huaweicloudsdkeg.v1.HeaderParameter`]
        """
        
        

        self._header_parameters = None
        self.discriminator = None

        if header_parameters is not None:
            self.header_parameters = header_parameters

    @property
    def header_parameters(self):
        """Gets the header_parameters of this InvocationHttpParameters.

        对象列表

        :return: The header_parameters of this InvocationHttpParameters.
        :rtype: list[:class:`huaweicloudsdkeg.v1.HeaderParameter`]
        """
        return self._header_parameters

    @header_parameters.setter
    def header_parameters(self, header_parameters):
        """Sets the header_parameters of this InvocationHttpParameters.

        对象列表

        :param header_parameters: The header_parameters of this InvocationHttpParameters.
        :type header_parameters: list[:class:`huaweicloudsdkeg.v1.HeaderParameter`]
        """
        self._header_parameters = header_parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvocationHttpParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeg-3.1.159-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/invocation_http_parameters.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InvocationHttpParameters:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'header_parameters': 'list[HeaderParameter]'
    }

    attribute_map = {
        'header_parameters': 'header_parameters'
    }

    def __init__(self, header_parameters=None):
        r"""InvocationHttpParameters

        The model defined in huaweicloud sdk

        :param header_parameters: 对象列表
        :type header_parameters: list[:class:`huaweicloudsdkeg.v1.HeaderParameter`]
        """
        
        

        self._header_parameters = None
        self.discriminator = None

        if header_parameters is not None:
            self.header_parameters = header_parameters

    @property
    def header_parameters(self):
        r"""Gets the header_parameters of this InvocationHttpParameters.

        对象列表

        :return: The header_parameters of this InvocationHttpParameters.
        :rtype: list[:class:`huaweicloudsdkeg.v1.HeaderParameter`]
        """
        return self._header_parameters

    @header_parameters.setter
    def header_parameters(self, header_parameters):
        r"""Sets the header_parameters of this InvocationHttpParameters.

        对象列表

        :param header_parameters: The header_parameters of this InvocationHttpParameters.
        :type header_parameters: list[:class:`huaweicloudsdkeg.v1.HeaderParameter`]
        """
        self._header_parameters = header_parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvocationHttpParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
